==> google_cloud_service_directory-0.5.0-py2.py3-none-any.whl: google/cloud/servicedirectory_v1/types/service.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import proto  # type: ignore


from google.cloud.servicedirectory_v1.types import endpoint


__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1", manifest={"Service",},
)


class Service(proto.Message):
    r"""An individual service. A service contains a name and optional
    metadata. A service must exist before
    [endpoints][google.cloud.servicedirectory.v1.Endpoint] can be added
    to it.

    Attributes:
        name (str):
            Immutable. The resource name for the service in the format
            ``projects/*/locations/*/namespaces/*/services/*``
        annotations (Sequence[google.cloud.servicedirectory_v1.types.Service.AnnotationsEntry]):
            Optional. Annotations for the service. This data can be
            consumed by service clients. Restrictions:

            -  The entire annotations dictionary may contain up to 2000
               characters, spread accoss all key-value pairs.
               Annotations that goes beyond any these limits will be
               rejected.
            -  Valid annotation keys have two segments: an optional
               prefix and name, separated by a slash (/). The name
               segment is required and must be 63 characters or less,
               beginning and ending with an alphanumeric character
               ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.),
               and alphanumerics between. The prefix is optional. If
               specified, the prefix must be a DNS subdomain: a series
               of DNS labels separated by dots (.), not longer than 253
               characters in total, followed by a slash (/). Annotations
               that fails to meet these requirements will be rejected.
            -  The '(*.)google.com/' and '(*.)googleapis.com/' prefixes
               are reserved for system annotations managed by Service
               Directory. If the user tries to write to these keyspaces,
               those entries will be silently ignored by the system.
               Note: This field is equivalent to the 'metadata' field in
               the v1beta1 API. They have the same syntax and read/write
               to the same location in Service Directory.
        endpoints (Sequence[google.cloud.servicedirectory_v1.types.Endpoint]):
            Output only. Endpoints associated with this
            service. Returned on LookupService.Resolve.
            Control plane clients should use
            RegistrationService.ListEndpoints.
    """

    name = proto.Field(proto.STRING, number=1)

    annotations = proto.MapField(proto.STRING, proto.STRING, number=4)

    endpoints = proto.RepeatedField(proto.MESSAGE, number=3, message=endpoint.Endpoint,)


__all__ = tuple(sorted(__protobuf__.manifest))

==> google_cloud_service_directory-1.3.1-py2.py3-none-any.whl: google/cloud/servicedirectory_v1/types/service.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import proto  # type: ignore

from google.cloud.servicedirectory_v1.types import endpoint


__protobuf__ = proto.module(
    package="google.cloud.servicedirectory.v1", manifest={"Service",},
)


class Service(proto.Message):
    r"""An individual service. A service contains a name and optional
    metadata. A service must exist before
    [endpoints][google.cloud.servicedirectory.v1.Endpoint] can be added
    to it.

    Attributes:
        name (str):
            Immutable. The resource name for the service in the format
            ``projects/*/locations/*/namespaces/*/services/*``.
        annotations (Sequence[google.cloud.servicedirectory_v1.types.Service.AnnotationsEntry]):
            Optional. Annotations for the service. This data can be
            consumed by service clients. Restrictions:

            -  The entire annotations dictionary may contain up to 2000
               characters, spread accoss all key-value pairs.
               Annotations that goes beyond any these limits will be
               rejected.
            -  Valid annotation keys have two segments: an optional
               prefix and name, separated by a slash (/). The name
               segment is required and must be 63 characters or less,
               beginning and ending with an alphanumeric character
               ([a-z0-9A-Z]) with dashes (-), underscores (_), dots (.),
               and alphanumerics between. The prefix is optional. If
               specified, the prefix must be a DNS subdomain: a series
               of DNS labels separated by dots (.), not longer than 253
               characters in total, followed by a slash (/). Annotations
               that fails to meet these requirements will be rejected.
            -  The '(*.)google.com/' and '(*.)googleapis.com/' prefixes
               are reserved for system annotations managed by Service
               Directory. If the user tries to write to these keyspaces,
               those entries will be silently ignored by the system.
               Note: This field is equivalent to the 'metadata' field in
               the v1beta1 API. They have the same syntax and read/write
               to the same location in Service Directory.
        endpoints (Sequence[google.cloud.servicedirectory_v1.types.Endpoint]):
            Output only. Endpoints associated with this
            service. Returned on LookupService.Resolve.
            Control plane clients should use
            RegistrationService.ListEndpoints.
    """

    name = proto.Field(proto.STRING, number=1,)
    annotations = proto.MapField(proto.STRING, proto.STRING, number=4,)
    endpoints = proto.RepeatedField(proto.MESSAGE, number=3, message=endpoint.Endpoint,)


__all__ = tuple(sorted(__protobuf__.manifest))
